@@ -23,7 +23,7 @@ randomCPT <- function(object, states=c("yes", "no")){
 }
 
 .formula2char <- function(f) {
-    unlist(gRbase::rhsf2list(f))
+    unlist(rhsf2list(f))
 }
 
 .namesDimnames <- function(x)
